import type { QueryResolvers, MutationResolvers } from 'types/graphql'

import { isProduction } from '@redwoodjs/api/logger'
import { ValidationError } from '@redwoodjs/graphql-server'

import { db } from 'src/lib/db'

const address = isProduction
  ? process.env.ADDRESS_PROD
  : process.env.ADDRESS_DEV

export const resume: QueryResolvers['resume'] = async () => {
  const resume = await db.resume.findFirst()

  if (resume) return resume
  else
    return {
      id: -1,
      fileId: `${address}/no_resume.pdf`,
    }
}

export const createResume: MutationResolvers['createResume'] = async ({
  input,
}) => {
  if (await db.resume.findFirst())
    throw new ValidationError('Resume already exists')
  else
    return db.resume.create({
      data: input,
    })
}

export const deleteResume: MutationResolvers['deleteResume'] = async () => {
  const resume = await db.resume.findFirst()

  if (!resume) throw new ValidationError('Resume does not exist')
  else
    return db.resume.delete({
      where: { id: resume.id },
    })
}
