import type {
  QueryResolvers,
  MutationResolvers,
  TagRelationResolvers,
} from 'types/graphql'

import { db } from 'src/lib/db'

export const tags: QueryResolvers['tags'] = () => db.tag.findMany()

export const tag: QueryResolvers['tag'] = ({ id }) =>
  db.tag.findUnique({
    where: { id },
  })

export const createTag: MutationResolvers['createTag'] = ({ input }) =>
  db.tag.create({
    data: input,
  })

export const updateTag: MutationResolvers['updateTag'] = ({ id, input }) =>
  db.tag.update({
    data: input,
    where: { id },
  })

export const deleteTag: MutationResolvers['deleteTag'] = ({ id }) =>
  db.tag.delete({
    where: { id },
  })

export const Tag: TagRelationResolvers = {
  projects: (_obj, { root }) =>
    db.tag.findUnique({ where: { id: root?.id } }).projects(),
}
