import { useState, useRef, useLayoutEffect } from 'react'

import { ContactCardPortrait } from 'types/graphql'

import SocialLinks from 'src/components/Social/SocialLinks/SocialLinks'

interface ContactCardProps {
  portraitUrl: string
  socials: ContactCardPortrait['socials']
}

const ContactCard = ({ portraitUrl, socials }: ContactCardProps) => {
  const [width, setWidth] = useState<number>(0)
  const [height, setHeight] = useState<number>(0)

  const observedDiv = useRef(null)

  useLayoutEffect(() => {
    if (!observedDiv.current) return

    const resizeObserver = new ResizeObserver(() => {
      if (observedDiv.current.offsetWidth !== width)
        setWidth(observedDiv.current.offsetWidth)

      if (observedDiv.current.offsetHeight !== height)
        setHeight(observedDiv.current.offsetHeight)
    })

    resizeObserver.observe(observedDiv.current)

    return function cleanup() {
      resizeObserver.disconnect()
    }
  }, [width, height])

  return (
    <>
      <style
        dangerouslySetInnerHTML={{
          /* Tailwind arbitrary classes (e.g h-[${height}px]) doesn't work? */
          __html: `
            .contact-me-image {
              width: ${width}px;
              height: auto;

              @media (min-width: 768px) {
                width: auto;
                min-height: 18.25rem;
                height: ${height}px;
              }
            }
          `,
        }}
      />

      <div className="flex items-center justify-center">
        <div className="card card-compact bg-base-100 shadow-xl md:card-side">
          <img
            className="contact-me-image rounded-box aspect-portrait p-2 object-cover"
            src={portraitUrl}
            alt={`${process.env.FIRST_NAME} ${process.env.LAST_NAME}`}
          />
          <div className="card-body mx-auto w-fit md:mx-0" ref={observedDiv}>
            <h2 className="card-title justify-center text-3xl pb-2 md:justify-start">
              Contact Me
            </h2>
            <div className="card-actions rounded-btn">
              <SocialLinks socials={socials} />
            </div>
          </div>
        </div>
      </div>
    </>
  )
}

export default ContactCard
