import { mdiChevronLeft, mdiChevronRight } from '@mdi/js'
import Icon from '@mdi/react'
import {
  add,
  eachDayOfInterval,
  endOfMonth,
  endOfWeek,
  format,
  getDay,
  isEqual,
  isSameMonth,
  isToday,
  parse,
  startOfWeek,
  sub,
} from 'date-fns'

interface DatePickerProps {
  date: Date
  setDate: React.Dispatch<React.SetStateAction<Date>>
  month: string
  setMonth: React.Dispatch<React.SetStateAction<string>>
}

const DatePicker = ({ date, setDate, month, setMonth }: DatePickerProps) => {
  const currentMonthFirstDay = parse(month, 'MMMM yyyy', new Date())

  const days = eachDayOfInterval({
    start: startOfWeek(currentMonthFirstDay),
    end: endOfWeek(endOfMonth(currentMonthFirstDay)),
  })

  return (
    <div className="max-w-fit bg-base-100 space-y-2 p-2 rounded-xl">
      <div className="flex justify-between items-center">
        <button
          type="button"
          onClick={() =>
            setMonth(
              format(sub(currentMonthFirstDay, { months: 1 }), 'MMMM yyyy')
            )
          }
          className="btn btn-sm btn-square btn-ghost"
        >
          <Icon path={mdiChevronLeft} className="size-5" />
        </button>

        <p>{format(currentMonthFirstDay, 'MMMM yyyy')}</p>

        <button
          type="button"
          onClick={() =>
            setMonth(
              format(add(currentMonthFirstDay, { months: 1 }), 'MMMM yyyy')
            )
          }
          className="btn btn-sm btn-square btn-ghost"
        >
          <Icon path={mdiChevronRight} className="size-5" />
        </button>
      </div>
      <div className="grid gap-2 border-y py-1 border-base-300 grid-cols-7 text-center">
        {['S', 'M', 'T', 'W', 'T', 'F', 'S  '].map((weekday, i) => (
          <div key={i}>{weekday}</div>
        ))}
      </div>
      <div className="grid gap-2 grid-cols-7 text-center">
        {days.map((day, i) => {
          const selected = isEqual(day, date)
          const isCurrentMonth = isSameMonth(day, currentMonthFirstDay)
          const today = isToday(day)
          const weekday = getDay(day)

          let btnColor = 'btn-ghost'

          if (!isCurrentMonth) btnColor += ' opacity-40'

          if (today) btnColor = 'btn-error'
          if (selected) btnColor = 'btn-primary'

          return (
            <div
              key={day.toString()}
              className={`${i === 0 && ['col-start-1', 'col-start-2', 'col-start-3', 'col-start-4', 'col-start-5', 'col-start-6', 'col-start-7'][weekday]}`}
            >
              <button
                type="button"
                onClick={() => setDate(day)}
                className={`btn btn-sm btn-square ${btnColor}`}
              >
                <time dateTime={format(day, 'yyyy-MM-dd')}>
                  {format(day, 'd')}
                </time>
              </button>
            </div>
          )
        })}
      </div>
    </div>
  )
}

export default DatePicker
