/* eslint-disable jsx-a11y/label-has-associated-control */
import { mdiDelete, mdiPlus } from '@mdi/js'
import Icon from '@mdi/react'

interface FormTextListProps {
  name: string
  hint?: string
  itemPlaceholder: string
  icon?: string
  list: string[]
  errors: boolean[]
  setList: React.Dispatch<React.SetStateAction<string[]>>
}

const FormTextList = ({
  name,
  hint,
  itemPlaceholder,
  icon,
  list,
  errors,
  setList,
}: FormTextListProps) => {
  return (
    <div className="flex flex-col space-y-2 bg-base-100 rounded-xl">
      <div className="flex space-x-2 justify-between">
        <div className="flex items-center">
          <p className="font-semibold text-center">{name}</p>
        </div>
        <div className="flex gap-2 items-center">
          {hint && (
            <p className="opacity-70 text-xs font-light text-center">{hint}</p>
          )}
          <button
            className="btn btn-square btn-sm"
            type="button"
            onClick={() => setList([...list, ''])}
          >
            <Icon path={mdiPlus} className="size-4" />
          </button>
        </div>
      </div>
      {list.map((item, i) => (
        <label
          className={`input input-bordered pr-2 flex items-center space-x-2 w-full ${errors[i] && 'input-error'}`}
          key={i}
        >
          <label
            className={`size-4 flex-none ${errors[i] ? 'text-error' : 'opacity-70'}`}
          >
            <Icon path={icon} />
          </label>
          <input
            type="text"
            placeholder={itemPlaceholder}
            className="flex-grow min-w-0"
            value={item}
            onChange={(e) =>
              setList(list.map((val, j) => (j === i ? e.target.value : val)))
            }
          />
          <button
            className="btn btn-square btn-error btn-sm flex-none"
            type="button"
            onClick={() => setList(list.filter((_, j) => j !== i))}
          >
            <Icon path={mdiDelete} className="size-4" />
          </button>
        </label>
      ))}
    </div>
  )
}

export default FormTextList
