import { useState, useRef, useEffect } from 'react'

import { mdiOpenInNew } from '@mdi/js'
import Icon from '@mdi/react'
import { Document, Page as PdfPage, pdfjs } from 'react-pdf'

import 'react-pdf/dist/Page/AnnotationLayer.css'
import 'react-pdf/dist/Page/TextLayer.css'

pdfjs.GlobalWorkerOptions.workerSrc = new URL(
  'pdfjs-dist/build/pdf.worker.min.mjs',
  import.meta.url
).toString()

interface PDFProps {
  url: string
  form?: boolean
}

const PDF = ({ url, form = false }: PDFProps) => {
  const [numPages, setNumPages] = useState<number>(0)
  function onLoadSuccess({ numPages }: { numPages: number }) {
    setNumPages(numPages)
  }

  const containerRef = useRef<HTMLDivElement>(null)
  const [containerWidth, setContainerWidth] = useState<number>(0)

  useEffect(() => {
    function updateWidth() {
      if (containerRef.current) {
        setContainerWidth(containerRef.current.clientWidth)
      }
    }
    updateWidth()
    window.addEventListener('resize', updateWidth)
    return () => window.removeEventListener('resize', updateWidth)
  }, [])

  return (
    <div
      ref={containerRef}
      className="overflow-auto flex justify-center"
      style={{
        width: 'calc(100vw - 1rem)',
        height: `calc(100vh - ${form ? '8.5rem' : '6rem'})`,
      }}
    >
      <a
        href={url}
        target="_blank"
        rel="noopener noreferrer"
        className="fixed top-20 left-0 z-10 m-2 p-2 rounded-xl btn btn-square btn-ghost shadow-lg"
      >
        <Icon path={mdiOpenInNew} size={1} className="text-gray-600" />
      </a>
      <Document file={url} onLoadSuccess={onLoadSuccess}>
        {Array.from({ length: numPages }, (_, i) => (
          <PdfPage
            key={i}
            pageNumber={i + 1}
            width={Math.min(containerWidth, 800)}
          />
        ))}
      </Document>
    </div>
  )
}

export default PDF
