import type { FindPortrait, FindPortraitVariables } from 'types/graphql'

import type {
  CellSuccessProps,
  CellFailureProps,
  TypedDocumentNode,
} from '@redwoodjs/web'

import CellEmpty from 'src/components/Cell/CellEmpty/CellEmpty'
import CellFailure from 'src/components/Cell/CellFailure/CellFailure'
import CellLoading from 'src/components/Cell/CellLoading/CellLoading'
import PortraitForm from 'src/components/Portrait/PortraitForm/PortraitForm'

export const QUERY: TypedDocumentNode<FindPortrait, FindPortraitVariables> =
  gql`
    query FindPortrait {
      portrait {
        id
        fileId
      }
    }
  `

export const Loading = () => <CellLoading />
export const Empty = () => <CellEmpty />
export const Failure = ({ error }: CellFailureProps<FindPortraitVariables>) => (
  <CellFailure error={error} />
)

export const Success = ({
  portrait,
}: CellSuccessProps<FindPortrait, FindPortraitVariables>) =>
  portrait.id === -1 ? <PortraitForm /> : <PortraitForm portrait={portrait} />
