import type { FindProjects, FindProjectsVariables } from 'types/graphql'

import type {
  CellSuccessProps,
  CellFailureProps,
  TypedDocumentNode,
} from '@redwoodjs/web'

import CellEmpty from 'src/components/Cell/CellEmpty/CellEmpty'
import CellFailure from 'src/components/Cell/CellFailure/CellFailure'
import CellLoading from 'src/components/Cell/CellLoading/CellLoading'
import Projects from 'src/components/Project/Projects'

export const QUERY: TypedDocumentNode<FindProjects, FindProjectsVariables> =
  gql`
    query FindProjects {
      projects {
        id
        title
        description
        images
        date
        links
        tags {
          id
          tag
          color
        }
      }
    }
  `

export const Loading = () => <CellLoading />
export const Empty = () => <CellEmpty />
export const Failure = ({ error }: CellFailureProps<FindProjects>) => (
  <CellFailure error={error} />
)
export const Success = ({
  projects,
}: CellSuccessProps<FindProjects, FindProjectsVariables>) => (
  <Projects projects={projects} />
)
