import type { FindProjects, FindProjectsVariables } from 'types/graphql'

import { routes } from '@redwoodjs/router'
import {
  type CellSuccessProps,
  type CellFailureProps,
  type TypedDocumentNode,
  Metadata,
} from '@redwoodjs/web'

import CellEmpty from 'src/components/Cell/CellEmpty/CellEmpty'
import CellFailure from 'src/components/Cell/CellFailure/CellFailure'
import CellLoading from 'src/components/Cell/CellLoading/CellLoading'
import ProjectsShowcaseList from 'src/components/ProjectsShowcaseList/ProjectsShowcaseList'

export const QUERY: TypedDocumentNode<FindProjects, FindProjectsVariables> =
  gql`
    query FindProjects {
      projects {
        id
        title
        description
        images
        date
        links
        tags {
          id
          tag
          color
        }
      }
    }
  `

export const Loading = () => <CellLoading />
export const Empty = () => <CellEmpty />
export const Failure = ({ error }: CellFailureProps<FindProjectsVariables>) => (
  <CellFailure error={error} />
)

export const Success = ({
  projects,
}: CellSuccessProps<FindProjects, FindProjectsVariables>) => (
  <>
    <Metadata
      title="Projects"
      og={{
        title: 'Projects',
        type: 'website',
        description: `${projects.length} projects`,
        url: routes.projects(),
      }}
    />
    <ProjectsShowcaseList projects={projects} />
  </>
)
