import type { AdminFindResume, AdminFindResumeVariables } from 'types/graphql'

import type {
  CellSuccessProps,
  CellFailureProps,
  TypedDocumentNode,
} from '@redwoodjs/web'

import CellEmpty from 'src/components/Cell/CellEmpty/CellEmpty'
import CellFailure from 'src/components/Cell/CellFailure/CellFailure'
import CellLoading from 'src/components/Cell/CellLoading/CellLoading'
import ResumeForm from 'src/components/Resume/ResumeForm/ResumeForm'

export const QUERY: TypedDocumentNode<
  AdminFindResume,
  AdminFindResumeVariables
> = gql`
  query AdminFindResume {
    resume {
      id
      fileId
    }
  }
`

export const Loading = () => <CellLoading />
export const Empty = () => <CellEmpty />
export const Failure = ({
  error,
}: CellFailureProps<AdminFindResumeVariables>) => <CellFailure error={error} />

export const Success = ({
  resume,
}: CellSuccessProps<AdminFindResume, AdminFindResumeVariables>) =>
  resume.id === -1 ? <ResumeForm /> : <ResumeForm resume={resume} />
