import type { FindResume, FindResumeVariables } from 'types/graphql'

import { routes } from '@redwoodjs/router'
import {
  type CellSuccessProps,
  type CellFailureProps,
  type TypedDocumentNode,
  Metadata,
} from '@redwoodjs/web'

import CellEmpty from 'src/components/Cell/CellEmpty/CellEmpty'
import CellFailure from 'src/components/Cell/CellFailure/CellFailure'
import CellLoading from 'src/components/Cell/CellLoading/CellLoading'
import Resume from 'src/components/Resume/Resume/Resume'

export const QUERY: TypedDocumentNode<FindResume, FindResumeVariables> = gql`
  query FindResume {
    resume {
      id
      fileId
    }
  }
`

export const Loading = () => <CellLoading />
export const Empty = () => <CellEmpty />
export const Failure = ({ error }: CellFailureProps<FindResumeVariables>) => (
  <CellFailure error={error} />
)

export const Success = ({
  resume,
}: CellSuccessProps<FindResume, FindResumeVariables>) => (
  <>
    <Metadata
      title="Contact"
      og={{
        title: 'Resume',
        type: 'website',
        url: routes.resume(),
      }}
    />
    <Resume resume={resume} />
  </>
)
