import type { FindSocials, FindSocialsVariables } from 'types/graphql'

import type {
  CellSuccessProps,
  CellFailureProps,
  TypedDocumentNode,
} from '@redwoodjs/web'

import CellEmpty from 'src/components/Cell/CellEmpty/CellEmpty'
import CellFailure from 'src/components/Cell/CellFailure/CellFailure'
import CellLoading from 'src/components/Cell/CellLoading/CellLoading'
import Socials from 'src/components/Social/Socials'

export const QUERY: TypedDocumentNode<FindSocials, FindSocialsVariables> = gql`
  query FindSocials {
    socials {
      id
      name
      type
      username
    }
  }
`

export const Loading = () => <CellLoading />

export const Empty = () => <CellEmpty />

export const Failure = ({ error }: CellFailureProps<FindSocials>) => (
  <CellFailure error={error} />
)

export const Success = ({
  socials,
}: CellSuccessProps<FindSocials, FindSocialsVariables>) => {
  return <Socials socials={socials} />
}
