import type {
  CreateTagMutation,
  CreateTagInput,
  CreateTagMutationVariables,
} from 'types/graphql'

import { navigate, routes } from '@redwoodjs/router'
import { useMutation } from '@redwoodjs/web'
import type { TypedDocumentNode } from '@redwoodjs/web'
import { toast } from '@redwoodjs/web/toast'

import TagForm from 'src/components/Tag/TagForm'

const CREATE_TAG_MUTATION: TypedDocumentNode<
  CreateTagMutation,
  CreateTagMutationVariables
> = gql`
  mutation CreateTagMutation($input: CreateTagInput!) {
    createTag(input: $input) {
      id
    }
  }
`

const NewTag = () => {
  const [createTag, { loading, error }] = useMutation(CREATE_TAG_MUTATION, {
    onCompleted: () => {
      toast.success('Tag created')
      navigate(routes.tags())
    },
    onError: (error) => toast.error(error.message),
  })

  const onSave = (input: CreateTagInput) => createTag({ variables: { input } })

  return (
    <div className="flex mx-auto max-w-80 sm:max-w-sm md:max-w-md lg:max-w-lg xl:max-w-xl 2xl:max-w-2xl justify-center">
      <div className="overflow-hidden w-full overflow-x-auto rounded-xl bg-base-100">
        <table className="table">
          <thead className="bg-base-200 font-syne">
            <tr>
              <th>New Tag</th>
            </tr>
          </thead>
          <tbody>
            <tr>
              <th>
                <TagForm onSave={onSave} error={error} loading={loading} />
              </th>
            </tr>
          </tbody>
        </table>
      </div>
    </div>
  )
}

export default NewTag
