import type { FindTagById, FindTagByIdVariables } from 'types/graphql'

import type {
  CellSuccessProps,
  CellFailureProps,
  TypedDocumentNode,
} from '@redwoodjs/web'

import CellEmpty from 'src/components/Cell/CellEmpty/CellEmpty'
import CellFailure from 'src/components/Cell/CellFailure/CellFailure'
import CellLoading from 'src/components/Cell/CellLoading/CellLoading'
import Tag from 'src/components/Tag/Tag'

export const QUERY: TypedDocumentNode<FindTagById, FindTagByIdVariables> = gql`
  query FindTagById($id: Int!) {
    tag: tag(id: $id) {
      id
      tag
      color
    }
  }
`

export const Loading = () => <CellLoading />

export const Empty = () => <CellEmpty />

export const Failure = ({ error }: CellFailureProps<FindTagByIdVariables>) => (
  <CellFailure error={error} />
)

export const Success = ({
  tag,
}: CellSuccessProps<FindTagById, FindTagByIdVariables>) => <Tag tag={tag} />
