import type { FindTags, FindTagsVariables } from 'types/graphql'

import type {
  CellSuccessProps,
  CellFailureProps,
  TypedDocumentNode,
} from '@redwoodjs/web'

import CellEmpty from 'src/components/Cell/CellEmpty/CellEmpty'
import CellFailure from 'src/components/Cell/CellFailure/CellFailure'
import CellLoading from 'src/components/Cell/CellLoading/CellLoading'
import Tags from 'src/components/Tag/Tags'

export const QUERY: TypedDocumentNode<FindTags, FindTagsVariables> = gql`
  query FindTags {
    tags {
      id
      tag
      color
    }
  }
`

export const Loading = () => <CellLoading />
export const Empty = () => <CellEmpty />
export const Failure = ({ error }: CellFailureProps<FindTags>) => (
  <CellFailure error={error} />
)
export const Success = ({
  tags,
}: CellSuccessProps<FindTags, FindTagsVariables>) => <Tags tags={tags} />
