import { useEffect, useState } from 'react'

import { FindTags } from 'types/graphql'

import { calculateLuminance } from 'src/lib/color'

interface TagsSelectorProps {
  selectedTags: FindTags['tags']
  setSelectedTags: React.Dispatch<React.SetStateAction<FindTags['tags']>>
}

const TagsSelector = ({
  tags: _tags,
  selectedTags,
  setSelectedTags,
}: FindTags & TagsSelectorProps) => {
  const [tags, setTags] = useState<FindTags['tags']>(
    _tags.filter((tag) => !selectedTags.some((t) => t.id === tag.id))
  )

  useEffect(() => {
    const newTags = _tags.filter(
      (tag) => !selectedTags.some((t) => t.id === tag.id)
    )
    setTags(newTags)
  }, [selectedTags, _tags])

  return (
    <div className="space-y-2">
      {tags.length > 0 && (
        <>
          <p className="font-semibold">Tags</p>
          <div className="flex flex-wrap gap-2 ">
            {tags.map((tag, i) => (
              <button
                key={i}
                type="button"
                className="badge active:scale-95"
                style={{
                  backgroundColor: tag.color,
                  color:
                    calculateLuminance(tag.color) > 0.5 ? 'black' : 'white',
                }}
                onClick={() => setSelectedTags([...selectedTags, tag])}
              >
                {tag.tag}
              </button>
            ))}
          </div>
        </>
      )}
      {selectedTags.length > 0 && (
        <>
          <p className="font-semibold">Selected</p>
          <div className="flex flex-wrap gap-2 ">
            {selectedTags.map((tag, i) => (
              <button
                key={i}
                type="button"
                className="badge active:scale-95"
                style={{
                  backgroundColor: tag.color,
                  color:
                    calculateLuminance(tag.color) > 0.5 ? 'black' : 'white',
                }}
                onClick={() =>
                  setSelectedTags(selectedTags.filter((t) => t.id !== tag.id))
                }
              >
                {tag.tag}
              </button>
            ))}
          </div>
        </>
      )}
    </div>
  )
}

export default TagsSelector
