import type { FindTags, FindTagsVariables } from 'types/graphql'

import { Link, routes } from '@redwoodjs/router'
import type {
  CellSuccessProps,
  CellFailureProps,
  TypedDocumentNode,
} from '@redwoodjs/web'

import CellFailure from 'src/components/Cell/CellFailure/CellFailure'
import CellLoading from 'src/components/Cell/CellLoading/CellLoading'

import TagsSelector from '../TagsSelector/TagsSelector'

export const QUERY: TypedDocumentNode<FindTags, FindTagsVariables> = gql`
  query FindTags {
    tags {
      id
      tag
      color
    }
  }
`

interface TagsSelectorCellProps {
  selectedTags: FindTags['tags']
  setSelectedTags: React.Dispatch<React.SetStateAction<FindTags['tags']>>
}

export const beforeQuery = (props: TagsSelectorCellProps) => {
  // eslint-disable-next-line @typescript-eslint/no-unused-vars
  const { selectedTags, setSelectedTags } = props

  return {
    variables: {
      selectedTags,
      setSelectedTags,
    },
    fetchPolicy: 'cache-and-network',
  }
}

export const Loading = () => <CellLoading />
export const Empty = () => (
  <div className="w-80 space-y-2">
    <p className="font-semibold">Tags</p>
    <p className="font-normal opacity-60">
      No tags yet,{' '}
      <Link
        className="link link-primary link-hover"
        target="_blank"
        to={routes.newTag()}
      >
        create one?
      </Link>
    </p>
  </div>
)
export const Failure = ({ error }: CellFailureProps<FindTags>) => (
  <CellFailure error={error} />
)
export const Success = ({
  tags,
  selectedTags,
  setSelectedTags,
}: CellSuccessProps<FindTags, FindTagsVariables> & TagsSelectorCellProps) => (
  <TagsSelector
    selectedTags={selectedTags}
    setSelectedTags={setSelectedTags}
    tags={tags}
  />
)
