import type { TitlesQuery, TitlesQueryVariables } from 'types/graphql'

import type {
  CellSuccessProps,
  CellFailureProps,
  TypedDocumentNode,
} from '@redwoodjs/web'

import CellFailure from 'src/components/Cell/CellFailure/CellFailure'
import CellLoading from 'src/components/Cell/CellLoading/CellLoading'

import { Titles } from '../Titles/Titles'

export const QUERY: TypedDocumentNode<TitlesQuery, TitlesQueryVariables> = gql`
  query TitlesQuery {
    titles {
      titles
    }
  }
`

interface TitleProps {
  className?: string
}

export const beforeQuery = ({ className = '' }: TitleProps) => {
  return {
    variables: {
      className,
    },
    fetchPolicy: 'cache-and-network',
  }
}

export const Loading = () => <CellLoading />
export const Failure = ({ error }: CellFailureProps<TitlesQueryVariables>) => (
  <CellFailure error={error} />
)

export const Success = ({
  titles: { titles },
  className = '',
}: CellSuccessProps<TitlesQuery> & TitleProps) => (
  <Titles className={className} titles={titles} />
)
