import { mdiMenu, mdiLogout, mdiCog } from '@mdi/js'
import Icon from '@mdi/react'

import { Link, routes, useRoutePath, useRoutePaths } from '@redwoodjs/router'

import { useAuth } from 'src/auth'
import ThemeToggle from 'src/components/ThemeToggle/ThemeToggle'
import ToasterWrapper from 'src/components/ToasterWrapper/ToasterWrapper'

interface NavbarRoute {
  name: string
  path: string
}

type NavbarLayoutProps = {
  children?: React.ReactNode
}

const NavbarLayout = ({ children }: NavbarLayoutProps) => {
  const routePaths = useRoutePaths()
  const routePath = useRoutePath()

  const { isAuthenticated, logOut } = useAuth()

  const navbarRoutes: NavbarRoute[] = [
    {
      name: 'Projects',
      path: routes.projects(),
    },
    {
      name: 'Résumé',
      path: routes.resume(),
    },
    {
      name: 'Contact',
      path: routes.contact(),
    },
  ]

  const navbarAdminRoutes: NavbarRoute[] = [
    {
      name: 'Socials',
      path: routes.socials(),
    },
    {
      name: 'Projects',
      path: routes.adminProjects(),
    },
    {
      name: 'Tags',
      path: routes.tags(),
    },
    {
      name: 'Portrait',
      path: routes.portrait(),
    },
    {
      name: 'Titles',
      path: routes.titles(),
    },
    {
      name: 'Résumé',
      path: routes.adminResume(),
    },
  ]

  const navbarButtons = () =>
    navbarRoutes.map((route, i) => (
      <Link key={i} to={route.path} className="btn btn-ghost btn-sm">
        {route.name}
      </Link>
    ))

  const navbarAdminButtons = () =>
    navbarAdminRoutes.map((route, i) => (
      <Link key={i} to={route.path} className="btn btn-ghost btn-sm">
        {route.name}
      </Link>
    ))

  return (
    <>
      <ToasterWrapper />
      <div className="sticky top-0 z-50 p-2">
        <div className="navbar rounded-xl bg-base-300 backdrop-blur bg-opacity-90 shadow-xl">
          <div
            className={`navbar-start space-x-2 ${!isAuthenticated && routePath === routePaths.home ? 'first:space-x-0' : 'lg:first:space-x-0'}`}
          >
            <div className="dropdown">
              <div
                tabIndex={0}
                role="button"
                className={`btn btn-square btn-ghost ${!isAuthenticated && routePath === routePaths.home ? 'hidden' : 'lg:hidden'}`}
              >
                <Icon path={mdiMenu} className="text-base-content-100 size-8" />
              </div>
              <div
                // eslint-disable-next-line jsx-a11y/no-noninteractive-tabindex
                tabIndex={0}
                className="menu dropdown-content -ml-2 mt-4 w-36 gap-2 rounded-box bg-base-200 shadow-xl"
              >
                {isAuthenticated && routePath !== routePaths.home && (
                  <p className="btn btn-active no-animation btn-sm btn-block">
                    Public
                  </p>
                )}
                {routePath !== routePaths.home && navbarButtons()}
                {isAuthenticated && (
                  <>
                    <p className="btn btn-active no-animation btn-sm btn-block">
                      Admin
                    </p>
                    {navbarAdminButtons()}
                    <button onClick={logOut} className="btn btn-error btn-sm">
                      Logout
                    </button>
                  </>
                )}
              </div>
            </div>
            <Link
              to={routes.home()}
              className="btn btn-ghost hidden font-syne text-xl sm:flex"
            >
              {process.env.FIRST_NAME + ' ' + process.env.LAST_NAME}
            </Link>
          </div>
          <div className="navbar-center">
            <Link
              to={routes.home()}
              className="btn btn-ghost font-syne text-xl sm:hidden"
            >
              {process.env.FIRST_NAME + ' ' + process.env.LAST_NAME}
            </Link>
          </div>
          <div className="navbar-center hidden lg:flex">
            <div className="space-x-2 font-syne">
              {routePath !== routePaths.home && navbarButtons()}
            </div>
          </div>
          <div className="navbar-end space-x-2">
            {isAuthenticated && (
              <div className="hidden space-x-2 lg:flex">
                <button className="btn btn-square btn-ghost" onClick={logOut}>
                  <Icon path={mdiLogout} className="size-8" />
                </button>
                <div className="dropdown">
                  <div
                    tabIndex={0}
                    role="button"
                    className="btn btn-square btn-ghost"
                  >
                    <Icon path={mdiCog} className="size-8" />
                  </div>
                  <ul
                    // eslint-disable-next-line jsx-a11y/no-noninteractive-tabindex
                    tabIndex={0}
                    className="menu dropdown-content -ml-8 mt-4 w-36 gap-2 rounded-box bg-base-200 shadow-xl"
                  >
                    {navbarAdminButtons()}
                  </ul>
                </div>
              </div>
            )}
            <ThemeToggle />
          </div>
        </div>
      </div>
      <div className="p-2 font-inter">
        <main>{children}</main>
      </div>
    </>
  )
}

export default NavbarLayout
