import { mdiHome, mdiPlus } from '@mdi/js'
import Icon from '@mdi/react'

import { Link, routes } from '@redwoodjs/router'

import ThemeToggle from 'src/components/ThemeToggle/ThemeToggle'
import ToasterWrapper from 'src/components/ToasterWrapper/ToasterWrapper'

type ScaffoldLayoutProps = {
  title: string
  titleTo: string
  buttonLabel: string
  buttonTo: string
  children: React.ReactNode
}

const ScaffoldLayout = ({
  title,
  titleTo,
  buttonLabel,
  buttonTo,
  children,
}: ScaffoldLayoutProps) => {
  return (
    <>
      <ToasterWrapper />
      <div className="sticky top-0 z-50 p-2">
        <div className="navbar rounded-xl bg-base-300 font-syne backdrop-blur bg-opacity-90 shadow-xl">
          <div className="navbar-start space-x-2">
            <Link to={routes.home()} className="btn btn-square btn-ghost">
              <Icon className="size-8" path={mdiHome} />
            </Link>
            <Link to={routes[titleTo]()} className="btn btn-ghost text-xl">
              {title}
            </Link>
          </div>
          <div className="navbar-end space-x-2">
            <ThemeToggle />
            {buttonLabel && buttonTo && (
              <>
                <Link
                  to={routes[buttonTo]()}
                  className="btn btn-primary hidden sm:flex"
                >
                  <Icon className="size-6" path={mdiPlus} /> {buttonLabel}
                </Link>
                <Link
                  to={routes[buttonTo]()}
                  className="btn btn-square btn-primary sm:hidden"
                >
                  <Icon className="size-8" path={mdiPlus} />
                </Link>
              </>
            )}
          </div>
        </div>
      </div>
      <div className="p-2 font-inter">
        <main>{children}</main>
      </div>
    </>
  )
}

export default ScaffoldLayout
