import { ReactElement } from 'react'

import {
  SiX,
  SiThreads,
  SiInstagram,
  SiFacebook,
  SiTiktok,
  SiYoutube,
  SiLinkedin,
  SiMatrix,
  SiGithub,
  SiGitea,
  SiLeetcode,
  SiBitbucket,
  SiDiscord,
  SiForgejo,
  SiGitlab,
  SiSteam,
  SiTwitch,
} from '@icons-pack/react-simple-icons'
import { mdiEmail, mdiLink, mdiPhone } from '@mdi/js'
import Icon from '@mdi/react'
import type { Handle, Social } from 'types/graphql'

export const baseUrls: Record<Handle, string> = {
  x: 'https://x.com/',
  threads: 'https://www.threads.net/@',
  instagram: 'https://www.instagram.com/',
  facebook: 'https://www.facebook.com/',
  tiktok: 'https://www.tiktok.com/@',
  youtube: 'https://www.youtube.com/@',
  steam: 'https://steamcommunity.com/id/',
  discord: 'https://discord.gg/',
  twitch: 'https://www.twitch.tv/',
  linkedin: 'https://www.linkedin.com/in/',
  matrix: 'https://matrix.to/#/',
  github: 'https://github.com/',
  gitea: '',
  forgejo: '',
  gitlab: 'https://gitlab.com/',
  bitbucket: 'https://bitbucket.org/',
  leetcode: 'https://leetcode.com/u/',
  email: 'mailto:',
  phone: 'tel:',
  custom: '',
}

const logoComponents: Record<Handle, ReactElement> = {
  x: <SiX className="text-x-light dark:text-x-dark" />,
  threads: <SiThreads className="text-threads-light dark:text-threads-dark" />,
  instagram: (
    <SiInstagram className="text-instagram-light dark:text-instagram-dark" />
  ),
  facebook: (
    <SiFacebook className="text-facebook-light dark:text-facebook-dark" />
  ),
  tiktok: <SiTiktok className="text-tiktok-light dark:text-tiktok-dark" />,
  youtube: <SiYoutube className="text-youtube-light dark:text-youtube-dark" />,
  steam: <SiSteam className="text-steam-light dark:text-steam-dark" />,
  discord: <SiDiscord className="text-discord-light dark:text-discord-dark" />,
  twitch: <SiTwitch className="text-twitch-light dark:text-twitch-dark" />,
  linkedin: (
    <SiLinkedin className="text-linkedin-light dark:text-linkedin-dark" />
  ),
  matrix: <SiMatrix className="text-matrix-light dark:text-matrix-dark" />,
  github: <SiGithub className="text-github-light dark:text-github-dark" />,
  gitea: <SiGitea className="text-gitea-light dark:text-gitea-dark" />,
  forgejo: <SiForgejo className="text-forgejo-light dark:text-forgejo-dark" />,
  gitlab: <SiGitlab className="text-gitlab-light dark:text-gitlab-dark" />,
  bitbucket: (
    <SiBitbucket className="text-bitbucket-light dark:text-bitbucket-dark" />
  ),
  leetcode: (
    <SiLeetcode className="text-leetcode-light dark:text-leetcode-dark" />
  ),
  email: <Icon path={mdiEmail} className="size-7" />,
  phone: <Icon path={mdiPhone} className="size-7" />,
  custom: <Icon path={mdiLink} className="size-7" />,
}

export const sortOrder: Social['type'][] = [
  'phone',
  'email',
  'custom',
  'matrix',
  'linkedin',
  'leetcode',
  'github',
  'gitea',
  'forgejo',
  'gitlab',
  'bitbucket',
  'youtube',
  'x',
  'instagram',
  'tiktok',
  'facebook',
  'threads',
  'twitch',
  'discord',
  'steam',
]

export const getLogoComponent = (type: Handle) => logoComponents[type]
