import { useEffect, useRef } from 'react'

import { mdiAccount } from '@mdi/js'
import Icon from '@mdi/react'

import { Form, Label, TextField, Submit, FieldError } from '@redwoodjs/forms'
import { navigate, routes } from '@redwoodjs/router'
import { Metadata } from '@redwoodjs/web'
import { toast } from '@redwoodjs/web/toast'

import { useAuth } from 'src/auth'

const ForgotPasswordPage = () => {
  const { isAuthenticated, forgotPassword } = useAuth()

  useEffect(() => {
    if (isAuthenticated) navigate(routes.home())
  }, [isAuthenticated])

  const emailRef = useRef<HTMLInputElement>(null)
  useEffect(() => {
    emailRef?.current?.focus()
  }, [])

  const onSubmit = async (data: { username: string }) => {
    toast.loading('Processing...', { id: `processing` })

    const response = await forgotPassword(data.username)

    if (response.error) toast.error(response.error, { id: `processing` })
    else {
      toast.success(
        `A link to reset your password was sent to ${response.email}`,
        { id: `processing` }
      )

      navigate(routes.login())
    }
  }

  return (
    <>
      <Metadata title="Forgot Password" />

      <div className="mx-auto my-32 flex w-fit flex-wrap items-center justify-center rounded-xl bg-base-100 p-2">
        <Form onSubmit={onSubmit} className="space-y-2">
          <Label
            name="username"
            className="input input-bordered flex items-center gap-2"
            errorClassName="input input-bordered flex items-center gap-2 input-error"
          >
            <Label
              name="username"
              className="size-4 opacity-70"
              errorClassName="size-4 text-error"
            >
              <Icon path={mdiAccount} />
            </Label>
            <TextField
              name="username"
              className="grow"
              placeholder="Username"
              ref={emailRef}
              validation={{
                required: {
                  value: true,
                  message: 'Required',
                },
              }}
            />
          </Label>
          <FieldError name="username" className="text-sm text-error" />

          <div className="flex w-full">
            <Submit className="btn btn-primary btn-sm mx-auto uppercase">
              Submit
            </Submit>
          </div>
        </Form>
      </div>
    </>
  )
}

export default ForgotPasswordPage
