import { mdiCodeBraces, mdiContacts, mdiFileDocument } from '@mdi/js'
import Icon from '@mdi/react'
import type { TCountryCode } from 'countries-list'
import { getCountryData } from 'countries-list'

import { Link, routes } from '@redwoodjs/router'
import { Metadata } from '@redwoodjs/web'

import TitlesCell from 'src/components/Title/TitlesCell'
import { getLogoComponent } from 'src/lib/handle'

const HomePage = () => (
  <>
    <Metadata
      title="Home"
      og={{
        title: `${process.env.FIRST_NAME} ${process.env.LAST_NAME}`,
        description: 'Check out my portfolio!',
        type: 'website',
        url: routes.home(),
      }}
    />

    <div className="hero min-h-[calc(100dvh-6rem)]">
      <div className="hero-content flex flex-col gap-8">
        <div className="flex flex-col text-center gap-8">
          <h1 className="text-4xl sm:text-5xl md:text-6xl lg:text-7xl font-bold">
            Hey 👋, I&apos;m {`${process.env.FIRST_NAME}`}
          </h1>
          <TitlesCell />
          <h3 className="text-xl">
            📍{' '}
            {[
              process.env.CITY,
              process.env.STATE,
              getCountryData(process.env.COUNTRY as TCountryCode).name,
            ]
              .filter((s) => s && s !== '')
              .join(', ')}
          </h3>
        </div>
        <div className="flex flex-col sm:flex-row gap-2">
          <Link
            to={routes.projects()}
            className="btn btn-primary btn-outline sm:w-40 sm:btn-lg"
          >
            <Icon path={mdiCodeBraces} className="size-6" />
            Projects
          </Link>
          <Link
            to={routes.resume()}
            className="btn btn-primary btn-outline sm:w-40 sm:btn-lg"
          >
            <Icon path={mdiFileDocument} className="size-6" />
            Résumé
          </Link>
          <Link
            to={routes.contact()}
            className="btn btn-primary btn-outline sm:w-40 sm:btn-lg"
          >
            <Icon path={mdiContacts} className="size-6" />
            Contact
          </Link>
        </div>
      </div>
    </div>
    <div className="fixed bottom-2 left-2 z-10">
      {process.env.APP_VERSION !== undefined ? (
        <div
          className="tooltip tooltip-right"
          data-tip={process.env.APP_VERSION}
        >
          <a
            href={`https://git.altaiar.dev/ahmed/portfolio/releases/tag/${process.env.APP_VERSION}`}
            target="_blank"
            rel="noreferrer"
            className="btn btn-square"
          >
            {getLogoComponent('gitea')}
          </a>
        </div>
      ) : (
        <a
          href={'https://git.altaiar.dev/ahmed/portfolio'}
          target="_blank"
          rel="noreferrer"
          className="btn btn-square"
        >
          {getLogoComponent('gitea')}
        </a>
      )}
    </div>
  </>
)

export default HomePage
